import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { $, clearNode, append } from 'vscode/vscode/vs/base/browser/dom';
import { Button } from 'vscode/vscode/vs/base/browser/ui/button/button';
import { getDefaultHoverDelegate } from 'vscode/vscode/vs/base/browser/ui/hover/hoverDelegateFactory';
import { Codicon } from 'vscode/vscode/vs/base/common/codicons';
import { Disposable, DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';
import { basename, dirname } from 'vscode/vscode/vs/base/common/resources';
import { URI } from 'vscode/vscode/vs/base/common/uri';
import { localize } from 'vscode/vscode/vs/nls';
import { FileKind } from 'vscode/vscode/vs/platform/files/common/files';
import { IHoverService } from 'vscode/vscode/vs/platform/hover/browser/hover.service';
import { ILabelService } from 'vscode/vscode/vs/platform/label/common/label.service';

let ImplicitContextAttachmentWidget = class ImplicitContextAttachmentWidget extends Disposable {
    constructor(attachment, resourceLabels, labelService, hoverService) {
        super();
        this.attachment = attachment;
        this.resourceLabels = resourceLabels;
        this.labelService = labelService;
        this.hoverService = hoverService;
        this.renderDisposables = this._register(( (new DisposableStore())));
        this.domNode = $('.chat-attached-context-attachment.show-file-icons.implicit');
        this.render();
    }
    render() {
        clearNode(this.domNode);
        this.renderDisposables.clear();
        this.domNode.classList.toggle('disabled', !this.attachment.enabled);
        const label = this.resourceLabels.create(this.domNode, { supportIcons: true });
        const file = URI.isUri(this.attachment.value) ? this.attachment.value : this.attachment.value.uri;
        const range = URI.isUri(this.attachment.value) || !this.attachment.isSelection ? undefined : this.attachment.value.range;
        const fileBasename = basename(file);
        const fileDirname = dirname(file);
        const friendlyName = `${fileBasename} ${fileDirname}`;
        const ariaLabel = range ? ( localize(
            10790,
            "Attached file, {0}, line {1} to line {2}",
            friendlyName,
            range.startLineNumber,
            range.endLineNumber
        )) : ( localize(10791, "Attached file, {0}", friendlyName));
        const uriLabel = this.labelService.getUriLabel(file, { relative: true });
        const currentFile = ( localize(10792, "Current file context"));
        const inactive = ( localize(10793, "disabled"));
        const currentFileHint = currentFile + (this.attachment.enabled ? '' : ` (${inactive})`);
        const title = `${currentFileHint}\n${uriLabel}`;
        label.setFile(file, {
            fileKind: FileKind.FILE,
            hidePath: true,
            range,
            title
        });
        this.domNode.ariaLabel = ariaLabel;
        this.domNode.tabIndex = 0;
        const hintElement = append(this.domNode, $('span.chat-implicit-hint', undefined, 'Current file'));
        this._register(this.hoverService.setupManagedHover(getDefaultHoverDelegate('element'), hintElement, title));
        const buttonMsg = this.attachment.enabled ? ( localize(10794, "Disable current file context")) : ( localize(10795, "Enable current file context"));
        const toggleButton = this.renderDisposables.add(( (new Button(this.domNode, { supportIcons: true, title: buttonMsg }))));
        toggleButton.icon = this.attachment.enabled ? Codicon.eye : Codicon.eyeClosed;
        this.renderDisposables.add(toggleButton.onDidClick((e) => {
            e.stopPropagation();
            this.attachment.enabled = !this.attachment.enabled;
        }));
    }
};
ImplicitContextAttachmentWidget = ( (__decorate([
    ( (__param(2, ILabelService))),
    ( (__param(3, IHoverService)))
], ImplicitContextAttachmentWidget)));

export { ImplicitContextAttachmentWidget };
